# coding: utf-8

"""
    Pulp 3 API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import pulpcore.client.pulp_rpm
from pulpcore.client.pulp_rpm.models.inline_response2002 import InlineResponse2002  # noqa: E501
from pulpcore.client.pulp_rpm.rest import ApiException


class TestInlineResponse2002(unittest.TestCase):
    """InlineResponse2002 unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testInlineResponse2002(self):
        """Test InlineResponse2002"""
        # FIXME: construct object with mandatory attributes with example values
        # model = pulpcore.client.pulp_rpm.models.inline_response2002.InlineResponse2002()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
