# coding: utf-8

"""
    Pulp 3 API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v3
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import unittest

import pulpcore.client.pulp_rpm
from pulpcore.client.pulp_rpm.api.publications_rpm_api import PublicationsRpmApi  # noqa: E501
from pulpcore.client.pulp_rpm.rest import ApiException


class TestPublicationsRpmApi(unittest.TestCase):
    """PublicationsRpmApi unit test stubs"""

    def setUp(self):
        self.api = pulpcore.client.pulp_rpm.api.publications_rpm_api.PublicationsRpmApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create(self):
        """Test case for create

        Create a rpm publication  # noqa: E501
        """
        pass

    def test_delete(self):
        """Test case for delete

        Delete a rpm publication  # noqa: E501
        """
        pass

    def test_list(self):
        """Test case for list

        List rpm publications  # noqa: E501
        """
        pass

    def test_read(self):
        """Test case for read

        Inspect a rpm publication  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
